@@ -1,5 +1,5 @@
 Merge <-
-function(data1, data2, by=NULL, quiet=getOption("quiet"), ...) {
+  function(data1, data2, by=NULL, quiet=getOption("quiet"), ...) {
 
   if (missing(data1)) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
@@ -14,28 +14,13 @@ function(data1, data2, by=NULL, quiet=getOption("quiet"), ...) {
   dname1 <- deparse(substitute(data1))
   dname2 <- deparse(substitute(data2))
 
-  if (!quiet) {
-    cat("\n")
-    .dash(17)
-    cat("Before the merge\n")
-    .dash(17)
-    cat("\n")
-    cat("First five rows of data for first data frame:", dname1, "\n")
-    .dash(68)
-    print(head(data1, n=5))
-    cat("\n")
-    cat("First five rows of data for second data frame:", dname2, "\n")
-    .dash(68)
-    print(head(data2, n=5))
-    cat("\n")
-  }
-
 
   # do the merge
   if (missing(by)) {
     if (!identical(names(data1), names(data2))) { 
       cat("\n"); stop(call.=FALSE, "\n","------\n",
-        "To do a vertical merge, both data sets must have the same variables.\n\n")
+        "To do a vertical merge, both data sets must have the same variables.",
+        "\n\n")
     }
     l <- attr(data1, which="variable.labels") # save variable labels
     myunits <- attr(data1, which="variable.units") # save variable units
@@ -55,18 +40,6 @@ function(data1, data2, by=NULL, quiet=getOption("quiet"), ...) {
   }
 
 
-  if (!quiet) {
-    cat("\n")
-    .dash(16+nchar(type))
-    cat("After the", type, "merge\n")
-    .dash(16+nchar(type))
-    cat("\n")
-    cat("First five rows of data ")
-    cat( "\n")
-    .dash(68)
-    print(head(data, n=5))
-  }
-
   # restore any variable labels, units
   if (!is.null(l)) attr(data, which="variable.labels") <- l
   if (!is.null(myunits)) attr(data, which="variable.units") <- myunits
